@@ -26,8 +26,7 @@
 #include <gpgme++/key.h>
 #include <gpgme++/keylistresult.h>
 
-namespace MessageComposer
-{
+namespace MessageComposer {
 class SignJob;
 }
 
@@ -47,7 +46,6 @@ private Q_SLOTS:
 
 private:
     void checkSignJob(MessageComposer::SignJob *sJob);
-
 };
 
 #endif
