@@ -22,8 +22,6 @@
 
 #include "attachmentcontrollerbase.h"
 
-
-
 #include <MessageComposer/AttachmentModel>
 #include "MessageComposer/AttachmentJob"
 #include "MessageComposer/AttachmentFromPublicKeyJob"
@@ -87,7 +85,7 @@ public:
     Private(AttachmentControllerBase *qq);
     ~Private();
 
-    void attachmentRemoved(AttachmentPart::Ptr part);   // slot
+    void attachmentRemoved(const AttachmentPart::Ptr &part);   // slot
     void compressJobResult(KJob *job);   // slot
     void loadJobResult(KJob *job);   // slot
     void openSelectedAttachments(); // slot
@@ -103,40 +101,40 @@ public:
     void addAttachmentPart(AttachmentPart::Ptr part);
     void attachVcardFromAddressBook(KJob *job);   //slot
     void selectedAllAttachment();
-    void createOpenWithMenu(QMenu *topMenu, AttachmentPart::Ptr part);
+    void createOpenWithMenu(QMenu *topMenu, const AttachmentPart::Ptr &part);
     void reloadAttachment();
     void updateJobResult(KJob *);
 
     AttachmentControllerBase *const q;
-    bool encryptEnabled;
-    bool signEnabled;
-    MessageComposer::AttachmentModel *model;
-    QWidget *wParent;
+    bool encryptEnabled = false;
+    bool signEnabled = false;
+    MessageComposer::AttachmentModel *model = nullptr;
+    QWidget *wParent = nullptr;
     QHash<MessageViewer::EditorWatcher *, AttachmentPart::Ptr> editorPart;
     QHash<MessageViewer::EditorWatcher *, QTemporaryFile *> editorTempFile;
 
     AttachmentPart::List selectedParts;
-    KActionCollection *mActionCollection;
-    QAction *attachPublicKeyAction;
-    QAction *attachMyPublicKeyAction;
-    QAction *openContextAction;
-    QAction *viewContextAction;
-    QAction *editContextAction;
-    QAction *editWithContextAction;
-    QAction *removeAction;
-    QAction *removeContextAction;
-    QAction *saveAsAction;
-    QAction *saveAsContextAction;
-    QAction *propertiesAction;
-    QAction *propertiesContextAction;
-    QAction *addAttachmentFileAction;
-    QAction *addAttachmentDirectoryAction;
-    QAction *addContextAction;
-    QAction *selectAllAction;
-    KActionMenu *attachmentMenu;
-    QAction *addOwnVcardAction;
-    QAction *reloadAttachmentAction;
-    QAction *attachVCardsAction;
+    KActionCollection *mActionCollection = nullptr;
+    QAction *attachPublicKeyAction = nullptr;
+    QAction *attachMyPublicKeyAction = nullptr;
+    QAction *openContextAction = nullptr;
+    QAction *viewContextAction = nullptr;
+    QAction *editContextAction = nullptr;
+    QAction *editWithContextAction = nullptr;
+    QAction *removeAction = nullptr;
+    QAction *removeContextAction = nullptr;
+    QAction *saveAsAction = nullptr;
+    QAction *saveAsContextAction = nullptr;
+    QAction *propertiesAction = nullptr;
+    QAction *propertiesContextAction = nullptr;
+    QAction *addAttachmentFileAction = nullptr;
+    QAction *addAttachmentDirectoryAction = nullptr;
+    QAction *addContextAction = nullptr;
+    QAction *selectAllAction = nullptr;
+    KActionMenu *attachmentMenu = nullptr;
+    QAction *addOwnVcardAction = nullptr;
+    QAction *reloadAttachmentAction = nullptr;
+    QAction *attachVCardsAction = nullptr;
 
     // If part p is compressed, uncompressedParts[p] is the uncompressed part.
     QHash<AttachmentPart::Ptr, AttachmentPart::Ptr> uncompressedParts;
@@ -144,31 +142,6 @@ public:
 
 AttachmentControllerBase::Private::Private(AttachmentControllerBase *qq)
     : q(qq)
-    , encryptEnabled(false)
-    , signEnabled(false)
-    , model(nullptr)
-    , wParent(nullptr)
-    , mActionCollection(nullptr)
-    , attachPublicKeyAction(nullptr)
-    , attachMyPublicKeyAction(nullptr)
-    , openContextAction(nullptr)
-    , viewContextAction(nullptr)
-    , editContextAction(nullptr)
-    , editWithContextAction(nullptr)
-    , removeAction(nullptr)
-    , removeContextAction(nullptr)
-    , saveAsAction(nullptr)
-    , saveAsContextAction(nullptr)
-    , propertiesAction(nullptr)
-    , propertiesContextAction(nullptr)
-    , addAttachmentFileAction(nullptr)
-    , addAttachmentDirectoryAction(nullptr)
-    , addContextAction(nullptr)
-    , selectAllAction(nullptr)
-    , attachmentMenu(nullptr)
-    , addOwnVcardAction(nullptr)
-    , reloadAttachmentAction(nullptr)
-    , attachVCardsAction(nullptr)
 {
 }
 
@@ -180,8 +153,8 @@ void AttachmentControllerBase::setSelectedParts(const AttachmentPart::List &sele
 {
     d->selectedParts = selectedParts;
     const int selectedCount = selectedParts.count();
-    const bool enableEditAction = (selectedCount == 1) &&
-                                  (!selectedParts.first()->isMessageOrMessageCollection());
+    const bool enableEditAction = (selectedCount == 1)
+                                  && (!selectedParts.first()->isMessageOrMessageCollection());
 
     d->openContextAction->setEnabled(selectedCount > 0);
     d->viewContextAction->setEnabled(selectedCount > 0);
@@ -195,7 +168,7 @@ void AttachmentControllerBase::setSelectedParts(const AttachmentPart::List &sele
     d->propertiesContextAction->setEnabled(selectedCount == 1);
 }
 
-void AttachmentControllerBase::Private::attachmentRemoved(AttachmentPart::Ptr part)
+void AttachmentControllerBase::Private::attachmentRemoved(const AttachmentPart::Ptr &part)
 {
     uncompressedParts.remove(part);
 }
@@ -215,11 +188,11 @@ void AttachmentControllerBase::Private::compressJobResult(KJob *job)
 
     if (ajob->isCompressedPartLarger()) {
         const int result = KMessageBox::questionYesNo(wParent,
-                           i18n("The compressed attachment is larger than the original. "
-                                "Do you want to keep the original one?"),
-                           QString(/*caption*/),
-                           KGuiItem(i18nc("Do not compress", "Keep")),
-                           KGuiItem(i18n("Compress")));
+                                                      i18n("The compressed attachment is larger than the original. "
+                                                           "Do you want to keep the original one?"),
+                                                      QString(/*caption*/),
+                                                      KGuiItem(i18nc("Do not compress", "Keep")),
+                                                      KGuiItem(i18n("Compress")));
         if (result == KMessageBox::Yes) {
             // The user has chosen to keep the uncompressed file.
             return;
@@ -344,7 +317,7 @@ void AttachmentControllerBase::Private::editDone(MessageViewer::EditorWatcher *w
     // The watcher deletes itself.
 }
 
-void AttachmentControllerBase::Private::createOpenWithMenu(QMenu *topMenu, AttachmentPart::Ptr part)
+void AttachmentControllerBase::Private::createOpenWithMenu(QMenu *topMenu, const AttachmentPart::Ptr &part)
 {
     const QString contentTypeStr = QString::fromLatin1(part->mimeType());
     const KService::List offers = KFileItemActions::associatedApplications(QStringList() << contentTypeStr, QString());
@@ -364,8 +337,8 @@ void AttachmentControllerBase::Private::createOpenWithMenu(QMenu *topMenu, Attac
         KService::List::ConstIterator end = offers.constEnd();
         for (; it != end; ++it) {
             QAction *act = MessageViewer::Util::createAppAction(*it,
-                           // no submenu -> prefix single offer
-                           menu == topMenu, actionGroup, menu);
+                                                                // no submenu -> prefix single offer
+                                                                menu == topMenu, actionGroup, menu);
             menu->addAction(act);
         }
 
@@ -396,7 +369,7 @@ void AttachmentControllerBase::exportPublicKey(const QString &fingerprint)
     }
 
     MessageComposer::AttachmentFromPublicKeyJob *ajob = new MessageComposer::AttachmentFromPublicKeyJob(fingerprint, this);
-    connect(ajob, SIGNAL(result(KJob*)), this, SLOT(attachPublicKeyJobResult(KJob*)));
+    connect(ajob, &AttachmentFromPublicKeyJob::result, this, [this](KJob *job) {d->attachPublicKeyJobResult(job); });
     ajob->start();
 }
 
@@ -451,8 +424,8 @@ AttachmentControllerBase::AttachmentControllerBase(MessageComposer::AttachmentMo
 {
     d->model = model;
     connect(model, &MessageComposer::AttachmentModel::attachUrlsRequested, this, &AttachmentControllerBase::addAttachments);
-    connect(model, SIGNAL(attachmentRemoved(MessageCore::AttachmentPart::Ptr)),
-            this, SLOT(attachmentRemoved(MessageCore::AttachmentPart::Ptr)));
+    connect(model, &MessageComposer::AttachmentModel::attachmentRemoved,
+            this, [this](const MessageCore::AttachmentPart::Ptr &attr) { d->attachmentRemoved(attr); });
     connect(model, &AttachmentModel::attachmentCompressRequested,
             this, &AttachmentControllerBase::compressAttachment);
     connect(model, &MessageComposer::AttachmentModel::encryptEnabled, this, &AttachmentControllerBase::setEncryptEnabled);
@@ -511,8 +484,8 @@ void AttachmentControllerBase::createActions()
 
     d->removeAction = new QAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18n("&Remove Attachment"), this);
     d->removeContextAction = new QAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18n("Remove"), this);     // FIXME need two texts. is there a better way?
-    connect(d->removeAction, SIGNAL(triggered(bool)), this, SLOT(removeSelectedAttachments()));
-    connect(d->removeContextAction, SIGNAL(triggered(bool)), this, SLOT(removeSelectedAttachments()));
+    connect(d->removeAction, &QAction::triggered, this, [this]() { d->removeSelectedAttachments(); });
+    connect(d->removeContextAction, &QAction::triggered, this, [this]() { d->removeSelectedAttachments(); });
 
     d->openContextAction = new QAction(i18nc("to open", "Open"), this);
     connect(d->openContextAction, SIGNAL(triggered(bool)), this, SLOT(openSelectedAttachments()));
@@ -579,7 +552,7 @@ void AttachmentControllerBase::setSignEnabled(bool enabled)
     d->signEnabled = enabled;
 }
 
-void AttachmentControllerBase::compressAttachment(AttachmentPart::Ptr part, bool compress)
+void AttachmentControllerBase::compressAttachment(const AttachmentPart::Ptr &part, bool compress)
 {
     if (compress) {
         qCDebug(MESSAGECOMPOSER_LOG) << "Compressing part.";
@@ -607,8 +580,8 @@ void AttachmentControllerBase::showContextMenu()
     const int numberOfParts(d->selectedParts.count());
     QMenu *menu = new QMenu;
 
-    const bool enableEditAction = (numberOfParts == 1) &&
-                                  (!d->selectedParts.first()->isMessageOrMessageCollection());
+    const bool enableEditAction = (numberOfParts == 1)
+                                  && (!d->selectedParts.first()->isMessageOrMessageCollection());
 
     if (numberOfParts > 0) {
         if (numberOfParts == 1) {
@@ -619,13 +592,13 @@ void AttachmentControllerBase::showContextMenu()
             if (mime.isValid()) {
                 parentMimeType = mime.allAncestors();
             }
-            if ((mimetype == QLatin1String("text/plain")) ||
-                    (mimetype == QLatin1String("image/png")) ||
-                    (mimetype == QLatin1String("image/jpeg")) ||
-                    parentMimeType.contains(QStringLiteral("text/plain")) ||
-                    parentMimeType.contains(QStringLiteral("image/png")) ||
-                    parentMimeType.contains(QStringLiteral("image/jpeg"))
-               ) {
+            if ((mimetype == QLatin1String("text/plain"))
+                || (mimetype == QLatin1String("image/png"))
+                || (mimetype == QLatin1String("image/jpeg"))
+                || parentMimeType.contains(QStringLiteral("text/plain"))
+                || parentMimeType.contains(QStringLiteral("image/png"))
+                || parentMimeType.contains(QStringLiteral("image/jpeg"))
+                ) {
                 menu->addAction(d->viewContextAction);
             }
             d->createOpenWithMenu(menu, d->selectedParts.first());
@@ -704,7 +677,7 @@ void AttachmentControllerBase::openWith(const KService::Ptr &offer)
     }
 }
 
-void AttachmentControllerBase::openAttachment(AttachmentPart::Ptr part)
+void AttachmentControllerBase::openAttachment(const AttachmentPart::Ptr &part)
 {
     QTemporaryFile *tempFile = dumpAttachmentToTempFile(part);
     if (!tempFile) {
@@ -714,11 +687,12 @@ void AttachmentControllerBase::openAttachment(AttachmentPart::Ptr part)
         return;
     }
     tempFile->setPermissions(QFile::ReadUser);
+    KRun::RunFlags flags;
+    flags |= KRun::DeleteTemporaryFiles;
     bool success = KRun::runUrl(QUrl::fromLocalFile(tempFile->fileName()),
                                 QString::fromLatin1(part->mimeType()),
                                 d->wParent,
-                                true /*tempFile*/,
-                                false /*runExecutables*/);
+                                flags);
     if (!success) {
         if (!KMimeTypeTrader::self()->preferredService(QString::fromLatin1(part->mimeType())).data()) {
             // KRun showed an Open-With dialog, and it was canceled.
@@ -737,7 +711,7 @@ void AttachmentControllerBase::openAttachment(AttachmentPart::Ptr part)
     }
 }
 
-void AttachmentControllerBase::viewAttachment(AttachmentPart::Ptr part)
+void AttachmentControllerBase::viewAttachment(const AttachmentPart::Ptr &part)
 {
     MessageComposer::Composer *composer = new MessageComposer::Composer;
     composer->globalPart()->setFallbackCharsetEnabled(true);
@@ -752,7 +726,9 @@ void AttachmentControllerBase::Private::slotAttachmentContentCreated(KJob *job)
     if (!job->error()) {
         const MessageComposer::AttachmentJob *const attachmentJob = dynamic_cast<MessageComposer::AttachmentJob *>(job);
         Q_ASSERT(attachmentJob);
-        Q_EMIT q->showAttachment(attachmentJob->content(), QByteArray());
+        if (attachmentJob) {
+            Q_EMIT q->showAttachment(attachmentJob->content(), QByteArray());
+        }
     } else {
         // TODO: show warning to the user
         qCWarning(MESSAGECOMPOSER_LOG) << "Error creating KMime::Content for attachment:" << job->errorText();
@@ -777,7 +753,7 @@ void AttachmentControllerBase::editAttachment(AttachmentPart::Ptr part, MessageV
             this, SLOT(editDone(MessageViewer::EditorWatcher*)));
 
     switch (watcher->start()) {
-    case MessageViewer::EditorWatcher::NoError: {
+    case MessageViewer::EditorWatcher::NoError:
         // The attachment is being edited.
         // We will clean things up in editDone().
         d->editorPart[ watcher ] = part;
@@ -786,28 +762,24 @@ void AttachmentControllerBase::editAttachment(AttachmentPart::Ptr part, MessageV
         // Delete the temp file if the composer is closed (and this object is destroyed).
         tempFile->setParent(this);   // Manages lifetime.
         break;
-    }
     case MessageViewer::EditorWatcher::CannotStart:
         qCWarning(MESSAGECOMPOSER_LOG) << "Could not start EditorWatcher.";
-#if QT_VERSION >= QT_VERSION_CHECK(5,8,0)
         Q_FALLTHROUGH();
-#endif
     case MessageViewer::EditorWatcher::Unknown:
     case MessageViewer::EditorWatcher::Canceled:
-    case MessageViewer::EditorWatcher::NoServiceFound: {
+    case MessageViewer::EditorWatcher::NoServiceFound:
         delete watcher;
         delete tempFile;
         break;
     }
-    }
 }
 
-void AttachmentControllerBase::editAttachmentWith(AttachmentPart::Ptr part)
+void AttachmentControllerBase::editAttachmentWith(const AttachmentPart::Ptr &part)
 {
     editAttachment(part, MessageViewer::EditorWatcher::OpenWithDialog);
 }
 
-void AttachmentControllerBase::saveAttachmentAs(AttachmentPart::Ptr part)
+void AttachmentControllerBase::saveAttachmentAs(const AttachmentPart::Ptr &part)
 {
     QString pname = part->name();
     if (pname.isEmpty()) {
@@ -838,17 +810,17 @@ void AttachmentControllerBase::slotPutResult(KJob *job)
         if (job->error() == KIO::ERR_FILE_ALREADY_EXIST) {
             if (KMessageBox::warningContinueCancel(nullptr,
                                                    i18n("File %1 exists.\nDo you want to replace it?", _job->url().toLocalFile()), i18n("Save to File"), KGuiItem(i18n("&Replace")))
-                    == KMessageBox::Continue) {
+                == KMessageBox::Continue) {
                 byteArrayToRemoteFile(_job->data(), _job->url(), true);
             }
         } else {
-            KJobUiDelegate *ui = static_cast<KIO::Job *>(job)->ui();
+            KJobUiDelegate *ui = static_cast<KIO::Job *>(job)->uiDelegate();
             ui->showErrorMessage();
         }
     }
 }
 
-void AttachmentControllerBase::attachmentProperties(AttachmentPart::Ptr part)
+void AttachmentControllerBase::attachmentProperties(const AttachmentPart::Ptr &part)
 {
     QPointer<AttachmentPropertiesDialog> dialog = new AttachmentPropertiesDialog(
         part, false, d->wParent);
@@ -865,7 +837,7 @@ void AttachmentControllerBase::attachmentProperties(AttachmentPart::Ptr part)
 void AttachmentControllerBase::attachDirectory(const QUrl &url)
 {
     const int rc = KMessageBox::warningYesNo(d->wParent, i18n("Do you really want to attach this directory \"%1\"?", url.toLocalFile()),
-                   i18nc("@title:window", "Attach directory"));
+                                             i18nc("@title:window", "Attach directory"));
     if (rc == KMessageBox::Yes) {
         addAttachment(url);
     }
@@ -891,7 +863,7 @@ void AttachmentControllerBase::showAttachVcard()
         const Akonadi::EmailAddressSelection::List selectedEmail = dlg->selectedAddresses();
         for (const Akonadi::EmailAddressSelection &selected : selectedEmail) {
             MessageComposer::AttachmentVcardFromAddressBookJob *ajob = new MessageComposer::AttachmentVcardFromAddressBookJob(selected.item(), this);
-            connect(ajob, SIGNAL(result(KJob*)), this, SLOT(attachVcardFromAddressBook(KJob*)));
+            connect(ajob, &AttachmentVcardFromAddressBookJob::result, this, [this](KJob *job) {d->attachVcardFromAddressBook(job);});
             ajob->start();
         }
     }
@@ -909,10 +881,10 @@ void AttachmentControllerBase::showAddAttachmentCompressedDirectoryDialog()
 void AttachmentControllerBase::showAddAttachmentFileDialog()
 {
     KEncodingFileDialog::Result result = KEncodingFileDialog::getOpenUrlsAndEncoding(QString(),
-                                         QUrl(),
-                                         QString(),
-                                         d->wParent,
-                                         i18nc("@title:window", "Attach File"));
+                                                                                     QUrl(),
+                                                                                     QString(),
+                                                                                     d->wParent,
+                                                                                     i18nc("@title:window", "Attach File"));
     if (!result.URLs.isEmpty()) {
         const QString encoding = MimeTreeParser::NodeHelper::fixEncoding(result.encoding);
         const int numberOfFiles(result.URLs.count());
@@ -924,7 +896,7 @@ void AttachmentControllerBase::showAddAttachmentFileDialog()
             auto mimeType = mimeDb.mimeTypeForUrl(urlWithEncoding);
             if (mimeType.name() == QLatin1String("inode/directory")) {
                 const int rc = KMessageBox::warningYesNo(d->wParent, i18n("Do you really want to attach this directory \"%1\"?", url.toLocalFile()),
-                               i18nc("@title:window", "Attach directory"));
+                                                         i18nc("@title:window", "Attach directory"));
                 if (rc == KMessageBox::Yes) {
                     addAttachment(urlWithEncoding);
                 }
@@ -935,7 +907,7 @@ void AttachmentControllerBase::showAddAttachmentFileDialog()
     }
 }
 
-void AttachmentControllerBase::addAttachment(AttachmentPart::Ptr part)
+void AttachmentControllerBase::addAttachment(const AttachmentPart::Ptr &part)
 {
     part->setEncrypted(d->model->isEncryptSelected());
     part->setSigned(d->model->isSignSelected());
@@ -983,7 +955,7 @@ void AttachmentControllerBase::showAttachPublicKeyDialog()
         false /* no remember choice box */,
         d->wParent);
 
-    if (dialog->exec() == QDialog::Accepted && dialog) {
+    if (dialog->exec() == QDialog::Accepted) {
         exportPublicKey(dialog->fingerprint());
     }
     delete dialog;
@@ -991,7 +963,6 @@ void AttachmentControllerBase::showAttachPublicKeyDialog()
 
 void AttachmentControllerBase::attachMyPublicKey()
 {
-
 }
 
 void AttachmentControllerBase::enableAttachPublicKey(bool enable)
@@ -1011,7 +982,7 @@ void AttachmentControllerBase::setAttachOwnVcard(bool attachVcard)
 
 bool AttachmentControllerBase::attachOwnVcard() const
 {
-    return  d->addOwnVcardAction->isChecked();
+    return d->addOwnVcardAction->isChecked();
 }
 
 void AttachmentControllerBase::setIdentityHasOwnVcard(bool state)
