@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -25,8 +25,7 @@
 #include <QImage>
 #include <QBuffer>
 
-namespace MessageComposer
-{
+namespace MessageComposer {
 class ImageScalingPrivate;
 class MESSAGECOMPOSER_EXPORT ImageScaling
 {
