@@ -46,9 +46,7 @@
 #include <QCryptographicHash>
 #include <QFontDatabase>
 
-namespace MessageList
-{
-
+namespace MessageList {
 class Q_DECL_HIDDEN StorageModel::Private
 {
 public:
@@ -58,26 +56,21 @@ public:
 
     StorageModel *const q;
 
-    QAbstractItemModel *mModel;
-    QAbstractItemModel *mChildrenFilterModel;
-    QItemSelectionModel *mSelectionModel;
+    QAbstractItemModel *mModel = nullptr;
+    QAbstractItemModel *mChildrenFilterModel = nullptr;
+    QItemSelectionModel *mSelectionModel = nullptr;
 
     Private(StorageModel *owner)
-        : q(owner),
-          mModel(nullptr),
-          mChildrenFilterModel(nullptr),
-          mSelectionModel(nullptr)
-    {}
+        : q(owner)
+    {
+    }
 };
-
 } // namespace MessageList
 
 using namespace Akonadi;
 using namespace MessageList;
 
-namespace
-{
-
+namespace {
 KMime::Message::Ptr messageForItem(const Akonadi::Item &item)
 {
     if (!item.hasPayload<KMime::Message::Ptr>()) {
@@ -86,13 +79,13 @@ KMime::Message::Ptr messageForItem(const Akonadi::Item &item)
     }
     return item.payload<KMime::Message::Ptr>();
 }
-
 }
 
 static QAtomicInt _k_attributeInitialized;
 
 StorageModel::StorageModel(QAbstractItemModel *model, QItemSelectionModel *selectionModel, QObject *parent)
-    : Core::StorageModel(parent), d(new Private(this))
+    : Core::StorageModel(parent)
+    , d(new Private(this))
 {
     d->mSelectionModel = selectionModel;
     if (_k_attributeInitialized.testAndSetAcquire(0, 1)) {
@@ -128,8 +121,8 @@ StorageModel::StorageModel(QAbstractItemModel *model, QItemSelectionModel *selec
     connect(d->mModel, &QAbstractItemModel::rowsAboutToBeRemoved, this, &StorageModel::rowsAboutToBeRemoved);
     connect(d->mModel, &QAbstractItemModel::rowsRemoved, this, &StorageModel::rowsRemoved);
 
-    connect(d->mSelectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-            this, SLOT(onSelectionChanged()));
+    connect(d->mSelectionModel, &QItemSelectionModel::selectionChanged,
+            this, [this]() { d->onSelectionChanged(); });
 
     d->loadSettings();
     connect(MessageListSettings::self(), SIGNAL(configChanged()),
@@ -175,7 +168,7 @@ QString StorageModel::id() const
 bool StorageModel::isOutBoundFolder(const Akonadi::Collection &c) const
 {
     if (c.hasAttribute<MessageFolderAttribute>()
-            && c.attribute<MessageFolderAttribute>()->isOutboundFolder()) {
+        && c.attribute<MessageFolderAttribute>()->isOutboundFolder()) {
         return true;
     }
     return false;
@@ -211,8 +204,7 @@ int StorageModel::initialUnreadRowCountGuess() const
     return unreadCount;
 }
 
-bool StorageModel::initializeMessageItem(MessageList::Core::MessageItem *mi,
-        int row, bool bUseReceiver) const
+bool StorageModel::initializeMessageItem(MessageList::Core::MessageItem *mi, int row, bool bUseReceiver) const
 {
     const Item item = itemForRow(row);
     const KMime::Message::Ptr mail = messageForItem(item);
@@ -285,34 +277,32 @@ static QByteArray md5Encode(const QString &str)
     return c.result();
 }
 
-void StorageModel::fillMessageItemThreadingData(MessageList::Core::MessageItem *mi,
-        int row, ThreadingDataSubset subset) const
+void StorageModel::fillMessageItemThreadingData(MessageList::Core::MessageItem *mi, int row, ThreadingDataSubset subset) const
 {
     const KMime::Message::Ptr mail = messageForRow(row);
     Q_ASSERT(mail);   // We ASSUME that initializeMessageItem has been called successfully...
 
     switch (subset) {
-    case PerfectThreadingReferencesAndSubject: {
+    case PerfectThreadingReferencesAndSubject:
+    {
         const QString subject = mail->subject()->asUnicodeString();
         const QString strippedSubject = MessageCore::StringUtil::stripOffPrefixes(subject);
         mi->setStrippedSubjectMD5(md5Encode(strippedSubject));
         mi->setSubjectIsPrefixed(subject != strippedSubject);
         // fall through
     }
-#if QT_VERSION >= QT_VERSION_CHECK(5,8,0)
         Q_FALLTHROUGH();
-#endif
-    case PerfectThreadingPlusReferences: {
+    case PerfectThreadingPlusReferences:
+    {
         const auto refs = mail->references()->identifiers();
         if (!refs.isEmpty()) {
             mi->setReferencesIdMD5(md5Encode(refs.last()));
         }
     }
-#if QT_VERSION >= QT_VERSION_CHECK(5,8,0)
         Q_FALLTHROUGH();
-#endif
     // fall through
-    case PerfectThreadingOnly: {
+    case PerfectThreadingOnly:
+    {
         mi->setMessageIdMD5(md5Encode(mail->messageID()->identifier()));
         const auto inReplyTos = mail->inReplyTo()->identifiers();
         if (!inReplyTos.isEmpty()) {
@@ -326,8 +316,7 @@ void StorageModel::fillMessageItemThreadingData(MessageList::Core::MessageItem *
     }
 }
 
-void StorageModel::updateMessageItemData(MessageList::Core::MessageItem *mi,
-        int row) const
+void StorageModel::updateMessageItemData(MessageList::Core::MessageItem *mi, int row) const
 {
     const Item item = itemForRow(row);
 
@@ -353,8 +342,7 @@ void StorageModel::updateMessageItemData(MessageList::Core::MessageItem *mi,
     mi->invalidateAnnotationCache();
 }
 
-void StorageModel::setMessageItemStatus(MessageList::Core::MessageItem *mi,
-                                        int row, Akonadi::MessageStatus status)
+void StorageModel::setMessageItemStatus(MessageList::Core::MessageItem *mi, int row, Akonadi::MessageStatus status)
 {
     Q_UNUSED(mi);
     Item item = itemForRow(row);
@@ -425,11 +413,6 @@ QMimeData *StorageModel::mimeData(const QList< MessageList::Core::MessageItem *
     return data;
 }
 
-void StorageModel::prepareForScan()
-{
-
-}
-
 void StorageModel::Private::onSourceDataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight)
 {
     Q_EMIT q->dataChanged(q->index(topLeft.row(), 0),
@@ -501,7 +484,8 @@ Collection StorageModel::parentCollectionForRow(int row) const
 
 void StorageModel::resetModelStorage()
 {
-    reset();
+    beginResetModel();
+    endResetModel();
 }
 
 #include "moc_storagemodel.cpp"
