@@ -21,12 +21,14 @@
 #include "messageviewer_debug.h"
 
 #include <AkonadiCore/ItemModifyJob>
+#include <AkonadiCore/Session>
 
 #include "viewer/messagedisplayformatattribute.h"
 
 using namespace MessageViewer;
-ModifyMessageDisplayFormatJob::ModifyMessageDisplayFormatJob(QObject *parent)
+ModifyMessageDisplayFormatJob::ModifyMessageDisplayFormatJob(Akonadi::Session *session, QObject *parent)
     : QObject(parent)
+    , mSession(session)
     , mMessageFormat(Viewer::UseGlobalSetting)
     , mRemoteContent(false)
     , mResetFormat(false)
@@ -74,7 +76,7 @@ void ModifyMessageDisplayFormatJob::setMessageItem(const Akonadi::Item &messageI
 void ModifyMessageDisplayFormatJob::resetDisplayFormat()
 {
     mMessageItem.removeAttribute<MessageViewer::MessageDisplayFormatAttribute>();
-    Akonadi::ItemModifyJob *modify = new Akonadi::ItemModifyJob(mMessageItem);
+    Akonadi::ItemModifyJob *modify = new Akonadi::ItemModifyJob(mMessageItem, mSession);
     modify->setIgnorePayload(true);
     modify->disableRevisionCheck();
     connect(modify, &KJob::result, this, &ModifyMessageDisplayFormatJob::slotModifyItemDone);
@@ -87,7 +89,7 @@ void ModifyMessageDisplayFormatJob::modifyDisplayFormat()
         Akonadi::Item::AddIfMissing);
     attr->setRemoteContent(mRemoteContent);
     attr->setMessageFormat(mMessageFormat);
-    Akonadi::ItemModifyJob *modify = new Akonadi::ItemModifyJob(mMessageItem);
+    Akonadi::ItemModifyJob *modify = new Akonadi::ItemModifyJob(mMessageItem, mSession);
     modify->setIgnorePayload(true);
     modify->disableRevisionCheck();
     connect(modify, &KJob::result, this, &ModifyMessageDisplayFormatJob::slotModifyItemDone);
