@@ -23,20 +23,17 @@
 
 #include "messageviewer_debug.h"
 
-#include "rendererpluginfactorysingleton.h"
 #include "converthtmltoplaintext.h"
 #include "messagepartrendererbase.h"
-#include "messagepartrendererfactorybase.h"
+#include "messagepartrendererfactory.h"
 #include "htmlblock.h"
-#include "partrendered.h"
 
 #include "utils/iconnamecache.h"
 #include "utils/mimetype.h"
 #include "viewer/csshelperbase.h"
 #include "messagepartrenderermanager.h"
 
-#include <MimeTreeParser/HtmlWriter>
-#include <MimeTreeParser/QueueHtmlWriter>
+#include <MimeTreeParser/BufferedHtmlWriter>
 #include <MimeTreeParser/MessagePart>
 #include <MimeTreeParser/ObjectTreeParser>
 #include <GrantleeTheme/QtResourceTemplateLoader>
@@ -62,14 +59,14 @@ using namespace MimeTreeParser;
 using namespace MessageViewer;
 
 Q_DECLARE_METATYPE(GpgME::DecryptionResult::Recipient)
+Q_DECLARE_METATYPE(GpgME::Key)
 Q_DECLARE_METATYPE(const QGpgME::Protocol *)
 
 static const int SIG_FRAME_COL_UNDEF = 99;
 #define SIG_FRAME_COL_RED    -1
 #define SIG_FRAME_COL_YELLOW  0
 #define SIG_FRAME_COL_GREEN   1
-QString sigStatusToString(const QGpgME::Protocol *cryptProto, int status_code,
-                          GpgME::Signature::Summary summary, int &frameColor, bool &showKeyInfos)
+QString sigStatusToString(const QGpgME::Protocol *cryptProto, int status_code, GpgME::Signature::Summary summary, int &frameColor, bool &showKeyInfos)
 {
     // note: At the moment frameColor and showKeyInfos are
     //       used for CMS only but not for PGP signatures
@@ -283,198 +280,121 @@ bool containsExternalReferences(const QString &str, const QString &extraHead)
     return false;
 }
 
-class CacheHtmlWriter : public MimeTreeParser::HtmlWriter
+// FIXME this used to go through the full webkit parser to extract the body and head blocks
+// until we have that back, at least attempt to fix some of the damage
+// yes, "parsing" HTML with regexps is very very wrong, but it's still better than not filtering
+// this at all...
+QString processHtml(const QString &htmlSource, QString &extraHead)
 {
-public:
-    explicit CacheHtmlWriter(MimeTreeParser::HtmlWriter *baseWriter)
-        : mBaseWriter(baseWriter)
-    {
+    auto s = htmlSource.trimmed();
+    s = s.replace(QRegExp(QStringLiteral("^<!DOCTYPE[^>]*>"), Qt::CaseInsensitive), QString()).trimmed();
+    s = s.replace(QRegExp(QStringLiteral("^<html[^>]*>"), Qt::CaseInsensitive), QString()).trimmed();
+
+    // head
+    s = s.replace(QRegExp(QStringLiteral("^<head/>"), Qt::CaseInsensitive), QString()).trimmed();
+    if (s.startsWith(QLatin1String("<head>", Qt::CaseInsensitive))) {
+        const auto idx = s.indexOf(QLatin1String("</head>"), Qt::CaseInsensitive);
+        if (idx < 0) {
+            return htmlSource;
+        }
+        extraHead = s.mid(6, idx - 6);
+        s = s.mid(idx + 7).trimmed();
     }
 
-    virtual ~CacheHtmlWriter()
-    {
-    }
+    // body
+    s = s.replace(QRegExp(QStringLiteral("<body[^>]*>"), Qt::CaseInsensitive), QString()).trimmed();
+    s = s.replace(QRegExp(QStringLiteral("</html>$"), Qt::CaseInsensitive), QString()).trimmed();
+    s = s.replace(QRegExp(QStringLiteral("</body>$"), Qt::CaseInsensitive), QString()).trimmed();
+    return s;
+}
 
-    void begin(const QString &text) override
-    {
-        mBaseWriter->begin(text);
-    }
-
-    void write(const QString &str) override
-    {
-        html.append(str);
-    }
-
-    void end() override
-    {
-        mBaseWriter->end();
-    }
-
-    void reset() override
-    {
-        mBaseWriter->reset();
-    }
-
-    void queue(const QString &str) override
-    {
-        html.append(str);
-    }
-
-    void flush() override
-    {
-        mBaseWriter->flush();
-    }
-
-    void embedPart(const QByteArray &contentId, const QString &url) override
-    {
-        mBaseWriter->embedPart(contentId, url);
-    }
-
-    void extraHead(const QString &extra) override
-    {
-        mBaseWriter->extraHead(extra);
-    }
-
-    QString html;
-    MimeTreeParser::HtmlWriter *mBaseWriter;
-};
-
-DefaultRendererPrivate::DefaultRendererPrivate(const Interface::MessagePart::Ptr &msgPart,
-                                               CSSHelperBase *cssHelper,
-                                               const MessagePartRendererFactoryBase *rendererFactory)
+DefaultRendererPrivate::DefaultRendererPrivate(const MessagePart::Ptr &msgPart, CSSHelperBase *cssHelper, HtmlWriter *writer, const MessagePartRendererFactory *rendererFactory)
     : mMsgPart(msgPart)
-    , mOldWriter(msgPart->htmlWriter())
     , mCSSHelper(cssHelper)
     , mRendererFactory(rendererFactory)
 {
-    mHtml = renderFactory(mMsgPart, QSharedPointer<CacheHtmlWriter>());
+    renderFactory(mMsgPart, writer);
 }
 
 DefaultRendererPrivate::~DefaultRendererPrivate()
 {
 }
 
-QString DefaultRendererPrivate::alignText()
-{
-    return QApplication::isRightToLeft() ? QStringLiteral("rtl") : QStringLiteral("ltr");
-}
-
 CSSHelperBase *DefaultRendererPrivate::cssHelper() const
 {
-    auto mp = mMsgPart.dynamicCast<MessagePart>();
-    if (mp) {
-        return mCSSHelper;
-    }
-    return nullptr;
+    return mCSSHelper;
 }
 
 Interface::ObjectTreeSource *DefaultRendererPrivate::source() const
 {
-    auto mp = mMsgPart.dynamicCast<MessagePart>();
-    if (mp) {
-        return mp->source();
-    }
-    return nullptr;
+    return mMsgPart->source();
 }
 
-void DefaultRendererPrivate::renderSubParts(const MessagePart::Ptr &msgPart,
-                                            const QSharedPointer<CacheHtmlWriter> &htmlWriter)
+void DefaultRendererPrivate::renderSubParts(const MessagePart::Ptr &msgPart, HtmlWriter *htmlWriter)
 {
-    foreach (const auto &_m, msgPart->subParts()) {
-        const auto m = _m.dynamicCast<MessagePart>();
-        if (m) {
-            htmlWriter->queue(renderFactory(m, htmlWriter));
-        } else {
-            auto hw = dynamic_cast<MimeTreeParser::QueueHtmlWriter *>(_m->htmlWriter());
-            if (hw) {
-                hw->setBase(htmlWriter.data());
-                _m->html(false);
-            }
-        }
+    foreach (const auto &m, msgPart->subParts()) {
+        renderFactory(m, htmlWriter);
     }
 }
 
-QString DefaultRendererPrivate::render(const MessagePartList::Ptr &mp)
+void DefaultRendererPrivate::render(const MessagePartList::Ptr &mp, HtmlWriter *htmlWriter)
 {
-    auto htmlWriter = QSharedPointer<CacheHtmlWriter>(new CacheHtmlWriter(mOldWriter));
-    {
-        HTMLBlock::Ptr rBlock;
-        HTMLBlock::Ptr aBlock;
+    HTMLBlock::Ptr rBlock;
+    HTMLBlock::Ptr aBlock;
 
-        if (mp->isRoot()) {
-            rBlock = HTMLBlock::Ptr(new RootBlock(htmlWriter.data()));
-        }
-
-        if (mp->isAttachment()) {
-            aBlock
-                = HTMLBlock::Ptr(new AttachmentMarkBlock(htmlWriter.data(), mp->attachmentNode()));
-        }
-
-        mp->setHtmlWriter(htmlWriter.data());
-        renderSubParts(mp, htmlWriter);
-        mp->setHtmlWriter(mOldWriter);
+    if (mp->isRoot()) {
+        rBlock = HTMLBlock::Ptr(new RootBlock(htmlWriter));
     }
 
-    return htmlWriter->html;
+    if (mp->isAttachment()) {
+        aBlock = HTMLBlock::Ptr(new AttachmentMarkBlock(htmlWriter, mp->attachmentContent()));
+    }
+
+    renderSubParts(mp, htmlWriter);
 }
 
-QString DefaultRendererPrivate::render(const MimeMessagePart::Ptr &mp)
+void DefaultRendererPrivate::render(const MimeMessagePart::Ptr &mp, HtmlWriter *htmlWriter)
 {
-    auto htmlWriter = QSharedPointer<CacheHtmlWriter>(new CacheHtmlWriter(mOldWriter));
-    {
-        HTMLBlock::Ptr aBlock;
-        HTMLBlock::Ptr rBlock;
-        if (mp->isAttachment()) {
-            aBlock
-                = HTMLBlock::Ptr(new AttachmentMarkBlock(htmlWriter.data(), mp->attachmentNode()));
-        }
-
-        if (mp->isRoot()) {
-            rBlock = HTMLBlock::Ptr(new RootBlock(htmlWriter.data()));
-        }
-
-        renderSubParts(mp, htmlWriter);
+    HTMLBlock::Ptr aBlock;
+    HTMLBlock::Ptr rBlock;
+    if (mp->isAttachment()) {
+        aBlock = HTMLBlock::Ptr(new AttachmentMarkBlock(htmlWriter, mp->attachmentContent()));
     }
 
-    return htmlWriter->html;
+    if (mp->isRoot()) {
+        rBlock = HTMLBlock::Ptr(new RootBlock(htmlWriter));
+    }
+
+    renderSubParts(mp, htmlWriter);
 }
 
-QString DefaultRendererPrivate::render(const EncapsulatedRfc822MessagePart::Ptr &mp)
+void DefaultRendererPrivate::render(const EncapsulatedRfc822MessagePart::Ptr &mp, HtmlWriter *htmlWriter)
 {
     if (!mp->hasSubParts()) {
-        return QString();
+        return;
     }
-    Grantlee::Template t = MessageViewer::MessagePartRendererManager::self()->loadByName(QStringLiteral(
-                                                                                             ":/encapsulatedrfc822messagepart.html"));
-    Grantlee::Context c = MessageViewer::MessagePartRendererManager::self()->createContext();
+    Grantlee::Template t = MessagePartRendererManager::self()->loadByName(QStringLiteral(":/encapsulatedrfc822messagepart.html"));
+    Grantlee::Context c = MessagePartRendererManager::self()->createContext();
     QObject block;
 
     c.insert(QStringLiteral("block"), &block);
-    block.setProperty("dir", alignText());
     block.setProperty("link",
-                      mp->mOtp->nodeHelper()->asHREF(mp->mMessage.data(), QStringLiteral("body")));
+                      mp->nodeHelper()->asHREF(mp->mMessage.data(), QStringLiteral("body")));
 
     c.insert(QStringLiteral("msgHeader"), mp->source()->createMessageHeader(mp->mMessage.data()));
-    {
-        auto _htmlWriter = QSharedPointer<CacheHtmlWriter>(new CacheHtmlWriter(mOldWriter));
-        renderSubParts(mp, _htmlWriter);
-        c.insert(QStringLiteral("content"), _htmlWriter->html);
-    }
+    c.insert(QStringLiteral("content"), QVariant::fromValue<GrantleeCallback>([this, mp, htmlWriter](Grantlee::OutputStream *) {
+        renderSubParts(mp, htmlWriter);
+    }));
 
-    auto htmlWriter = QSharedPointer<CacheHtmlWriter>(new CacheHtmlWriter(mOldWriter));
-    {
-        HTMLBlock::Ptr aBlock;
-        if (mp->isAttachment()) {
-            aBlock
-                = HTMLBlock::Ptr(new AttachmentMarkBlock(htmlWriter.data(), mp->attachmentNode()));
-        }
-        const auto html = t->render(&c);
-        htmlWriter->queue(html);
+    HTMLBlock::Ptr aBlock;
+    if (mp->isAttachment()) {
+        aBlock = HTMLBlock::Ptr(new AttachmentMarkBlock(htmlWriter, mp->attachmentContent()));
     }
-    return htmlWriter->html;
+    Grantlee::OutputStream s(htmlWriter->stream());
+    t->render(&s, &c);
 }
 
-QString DefaultRendererPrivate::render(const HtmlMessagePart::Ptr &mp)
+void DefaultRendererPrivate::render(const HtmlMessagePart::Ptr &mp, HtmlWriter *htmlWriter)
 {
     Grantlee::Template t = MessageViewer::MessagePartRendererManager::self()->loadByName(QStringLiteral(
                                                                                              ":/htmlmessagepart.html"));
@@ -492,11 +412,11 @@ QString DefaultRendererPrivate::render(const HtmlMessagePart::Ptr &mp)
     {
         QString extraHead;
         //laurent: FIXME port to async method webengine
-        QString bodyText = mp->mBodyHTML;//processHtml(mp->mBodyHTML, extraHead);
+        QString bodyText = processHtml(mp->mBodyHTML, extraHead);
 
         if (isHtmlPreferred) {
-            mp->mOtp->nodeHelper()->setNodeDisplayedEmbedded(mp->mNode, true);
-            mOldWriter->extraHead(extraHead);
+            mp->nodeHelper()->setNodeDisplayedEmbedded(mp->content(), true);
+            htmlWriter->extraHead(extraHead);
         }
 
         block.setProperty("containsExternalReferences",
@@ -513,23 +433,18 @@ QString DefaultRendererPrivate::render(const HtmlMessagePart::Ptr &mp)
     }
     mp->source()->setHtmlMode(Util::Html, QList<Util::HtmlMode>() << Util::Html);
 
-    auto htmlWriter = QSharedPointer<CacheHtmlWriter>(new CacheHtmlWriter(mOldWriter));
-    {
-        HTMLBlock::Ptr aBlock;
-        if (mp->isAttachment()) {
-            aBlock
-                = HTMLBlock::Ptr(new AttachmentMarkBlock(htmlWriter.data(), mp->attachmentNode()));
-        }
-        const auto html = t->render(&c);
-        htmlWriter->queue(html);
+    HTMLBlock::Ptr aBlock;
+    if (mp->isAttachment()) {
+        aBlock = HTMLBlock::Ptr(new AttachmentMarkBlock(htmlWriter, mp->attachmentContent()));
     }
-    return htmlWriter->html;
+    Grantlee::OutputStream s(htmlWriter->stream());
+    t->render(&s, &c);
 }
 
-QString DefaultRendererPrivate::renderEncrypted(const EncryptedMessagePart::Ptr &mp)
+void DefaultRendererPrivate::renderEncrypted(const EncryptedMessagePart::Ptr &mp, HtmlWriter *htmlWriter)
 {
-    KMime::Content *node = mp->mNode;
-    const auto metaData = mp->mMetaData;
+    KMime::Content *node = mp->content();
+    const auto metaData = *mp->partMetaData();
 
     Grantlee::Template t = MessageViewer::MessagePartRendererManager::self()->loadByName(QStringLiteral(
                                                                                              ":/encryptedmessagepart.html"));
@@ -537,32 +452,26 @@ QString DefaultRendererPrivate::renderEncrypted(const EncryptedMessagePart::Ptr
     QObject block;
 
     if (node || mp->hasSubParts()) {
-        auto _htmlWriter = QSharedPointer<CacheHtmlWriter>(new CacheHtmlWriter(mOldWriter));
-        {
+        c.insert(QStringLiteral("content"), QVariant::fromValue<GrantleeCallback>([this, mp, htmlWriter](Grantlee::OutputStream *) {
             HTMLBlock::Ptr rBlock;
-            if (node && mp->isRoot()) {
-                rBlock = HTMLBlock::Ptr(new RootBlock(_htmlWriter.data()));
+            if (mp->content() && mp->isRoot()) {
+                rBlock = HTMLBlock::Ptr(new RootBlock(htmlWriter));
             }
-            renderSubParts(mp, _htmlWriter);
-        }
-        c.insert(QStringLiteral("content"), _htmlWriter->html);
+            renderSubParts(mp, htmlWriter);
+        }));
     } else if (!metaData.inProgress) {
-        auto part = renderWithFactory(QStringLiteral("MimeTreeParser::MessagePart"), mp);
-        if (part) {
-            c.insert(QStringLiteral("content"), part->html());
-        } else {
-            c.insert(QStringLiteral("content"), QString());
-        }
+        c.insert(QStringLiteral("content"), QVariant::fromValue<GrantleeCallback>([this, mp, htmlWriter](Grantlee::OutputStream *) {
+            renderWithFactory<MimeTreeParser::MessagePart>(mp, htmlWriter);
+        }));
     }
 
     c.insert(QStringLiteral("cryptoProto"), QVariant::fromValue(mp->mCryptoProto));
-    if (mp->mDecryptRecipients.size() > 0) {
+    if (!mp->mDecryptRecipients.empty()) {
         c.insert(QStringLiteral("decryptedRecipients"),
                  QVariant::fromValue(mp->mDecryptRecipients));
     }
     c.insert(QStringLiteral("block"), &block);
 
-    block.setProperty("dir", alignText());
     block.setProperty("inProgress", metaData.inProgress);
     block.setProperty("isDecrypted", mp->decryptMessage());
     block.setProperty("isDecryptable", metaData.isDecryptable);
@@ -572,18 +481,15 @@ QString DefaultRendererPrivate::renderEncrypted(const EncryptedMessagePart::Ptr
                                                                               KIconLoader::Small)).url());
     block.setProperty("errorText", metaData.errorText);
     block.setProperty("noSecKey", mp->mNoSecKey);
-    block.setProperty("iconSize",
-                      MessageViewer::MessagePartRendererManager::self()->iconCurrentSize());
 
-    const auto html = t->render(&c);
-
-    return html;
+    Grantlee::OutputStream s(htmlWriter->stream());
+    t->render(&s, &c);
 }
 
-QString DefaultRendererPrivate::renderSigned(const SignedMessagePart::Ptr &mp)
+void DefaultRendererPrivate::renderSigned(const SignedMessagePart::Ptr &mp, HtmlWriter *htmlWriter)
 {
-    KMime::Content *node = mp->mNode;
-    const auto metaData = mp->mMetaData;
+    KMime::Content *node = mp->content();
+    const auto metaData = *mp->partMetaData();
     auto cryptoProto = mp->mCryptoProto;
 
     const bool isSMIME = cryptoProto && (cryptoProto == QGpgME::smime());
@@ -594,28 +500,22 @@ QString DefaultRendererPrivate::renderSigned(const SignedMessagePart::Ptr &mp)
     QObject block;
 
     if (node) {
-        auto _htmlWriter = QSharedPointer<CacheHtmlWriter>(new CacheHtmlWriter(mOldWriter));
-        {
+        c.insert(QStringLiteral("content"), QVariant::fromValue<GrantleeCallback>([this, mp, htmlWriter](Grantlee::OutputStream *) {
             HTMLBlock::Ptr rBlock;
             if (mp->isRoot()) {
-                rBlock = HTMLBlock::Ptr(new RootBlock(_htmlWriter.data()));
+                rBlock = HTMLBlock::Ptr(new RootBlock(htmlWriter));
             }
-            renderSubParts(mp, _htmlWriter);
-        }
-        c.insert(QStringLiteral("content"), _htmlWriter->html);
+            renderSubParts(mp, htmlWriter);
+        }));
     } else if (!metaData.inProgress) {
-        auto part = renderWithFactory(QStringLiteral("MimeTreeParser::MessagePart"), mp);
-        if (part) {
-            c.insert(QStringLiteral("content"), part->html());
-        } else {
-            c.insert(QStringLiteral("content"), QString());
-        }
+        c.insert(QStringLiteral("content"), QVariant::fromValue<GrantleeCallback>([this, mp, htmlWriter](Grantlee::OutputStream *) {
+            renderWithFactory<MimeTreeParser::MessagePart>(mp, htmlWriter);
+        }));
     }
 
     c.insert(QStringLiteral("cryptoProto"), QVariant::fromValue(cryptoProto));
     c.insert(QStringLiteral("block"), &block);
 
-    block.setProperty("dir", alignText());
     block.setProperty("inProgress", metaData.inProgress);
     block.setProperty("errorText", metaData.errorText);
 
@@ -789,7 +689,8 @@ QString DefaultRendererPrivate::renderSigned(const SignedMessagePart::Ptr &mp)
                                                                                                toPercentEncoding(
                                                                                                    address
                                                                                                    .
-                        path())), signer);
+                                                                                                   path())),
+                                                                                 signer);
                     }
                 }
             }
@@ -822,112 +723,83 @@ QString DefaultRendererPrivate::renderSigned(const SignedMessagePart::Ptr &mp)
     block.setProperty("signClass", mClass);
     block.setProperty("greenCaseWarning", greenCaseWarning);
 
-    const auto html = t->render(&c);
-
-    return html;
+    Grantlee::OutputStream s(htmlWriter->stream());
+    t->render(&s, &c);
 }
 
-QString DefaultRendererPrivate::render(const SignedMessagePart::Ptr &mp)
+void DefaultRendererPrivate::render(const SignedMessagePart::Ptr &mp, HtmlWriter *htmlWriter)
 {
-    auto htmlWriter = QSharedPointer<CacheHtmlWriter>(new CacheHtmlWriter(mOldWriter));
-    const auto metaData = mp->mMetaData;
+    const auto metaData = *mp->partMetaData();
     if (metaData.isSigned || metaData.inProgress) {
-        {
-            HTMLBlock::Ptr aBlock;
-            if (mp->isAttachment()) {
-                aBlock
-                    = HTMLBlock::Ptr(new AttachmentMarkBlock(htmlWriter.data(),
-                                                             mp->attachmentNode()));
-            }
-            htmlWriter->queue(renderSigned(mp));
-        }
-        return htmlWriter->html;
-    }
-    {
         HTMLBlock::Ptr aBlock;
         if (mp->isAttachment()) {
-            aBlock
-                = HTMLBlock::Ptr(new AttachmentMarkBlock(htmlWriter.data(), mp->attachmentNode()));
-        }
-        if (mp->hasSubParts()) {
-            renderSubParts(mp, htmlWriter);
-        } else if (!metaData.inProgress) {
-            auto part = renderWithFactory(QStringLiteral("MimeTreeParser::MessagePart"), mp);
-            if (part) {
-                htmlWriter->queue(part->html());
-            }
+            aBlock = HTMLBlock::Ptr(new AttachmentMarkBlock(htmlWriter, mp->attachmentContent()));
         }
+        renderSigned(mp, htmlWriter);
+        return;
+    }
+
+    HTMLBlock::Ptr aBlock;
+    if (mp->isAttachment()) {
+        aBlock = HTMLBlock::Ptr(new AttachmentMarkBlock(htmlWriter, mp->attachmentContent()));
+    }
+    if (mp->hasSubParts()) {
+        renderSubParts(mp, htmlWriter);
+    } else if (!metaData.inProgress) {
+        renderWithFactory<MimeTreeParser::MessagePart>(mp, htmlWriter);
     }
-    return htmlWriter->html;
 }
 
-QString DefaultRendererPrivate::render(const EncryptedMessagePart::Ptr &mp)
+void DefaultRendererPrivate::render(const EncryptedMessagePart::Ptr &mp, HtmlWriter *htmlWriter)
 {
-    auto htmlWriter = QSharedPointer<CacheHtmlWriter>(new CacheHtmlWriter(mOldWriter));
-    const auto metaData = mp->mMetaData;
+    const auto metaData = *mp->partMetaData();
 
     if (metaData.isEncrypted || metaData.inProgress) {
-        {
-            HTMLBlock::Ptr aBlock;
-            if (mp->isAttachment()) {
-                aBlock
-                    = HTMLBlock::Ptr(new AttachmentMarkBlock(htmlWriter.data(),
-                                                             mp->attachmentNode()));
-            }
-            htmlWriter->queue(renderEncrypted(mp));
-        }
-        return htmlWriter->html;
-    }
-
-    {
         HTMLBlock::Ptr aBlock;
         if (mp->isAttachment()) {
-            aBlock
-                = HTMLBlock::Ptr(new AttachmentMarkBlock(htmlWriter.data(), mp->attachmentNode()));
-        }
-
-        if (mp->hasSubParts()) {
-            renderSubParts(mp, htmlWriter);
-        } else if (!metaData.inProgress) {
-            auto part = renderWithFactory(QStringLiteral("MimeTreeParser::MessagePart"), mp);
-            if (part) {
-                htmlWriter->queue(part->html());
-            }
+            aBlock = HTMLBlock::Ptr(new AttachmentMarkBlock(htmlWriter, mp->attachmentContent()));
         }
+        renderEncrypted(mp, htmlWriter);
+        return;
+    }
+
+    HTMLBlock::Ptr aBlock;
+    if (mp->isAttachment()) {
+        aBlock = HTMLBlock::Ptr(new AttachmentMarkBlock(htmlWriter, mp->attachmentContent()));
+    }
+
+    if (mp->hasSubParts()) {
+        renderSubParts(mp, htmlWriter);
+    } else if (!metaData.inProgress) {
+        renderWithFactory<MimeTreeParser::MessagePart>(mp, htmlWriter);
     }
-    return htmlWriter->html;
 }
 
-QString DefaultRendererPrivate::render(const AlternativeMessagePart::Ptr &mp)
+void DefaultRendererPrivate::render(const AlternativeMessagePart::Ptr &mp, HtmlWriter *htmlWriter)
 {
-    auto htmlWriter = QSharedPointer<CacheHtmlWriter>(new CacheHtmlWriter(mOldWriter));
-    {
-        HTMLBlock::Ptr aBlock;
-        if (mp->isAttachment()) {
-            aBlock
-                = HTMLBlock::Ptr(new AttachmentMarkBlock(htmlWriter.data(), mp->attachmentNode()));
-        }
+    HTMLBlock::Ptr aBlock;
+    if (mp->isAttachment()) {
+        aBlock = HTMLBlock::Ptr(new AttachmentMarkBlock(htmlWriter, mp->attachmentContent()));
+    }
 
-        auto mode = mp->preferredMode();
-        if (mode == MimeTreeParser::Util::MultipartPlain && mp->text().trimmed().isEmpty()) {
-            foreach (const auto m, mp->availableModes()) {
-                if (m != MimeTreeParser::Util::MultipartPlain) {
-                    mode = m;
-                    break;
-                }
+    auto mode = mp->preferredMode();
+    if (mode == MimeTreeParser::Util::MultipartPlain && mp->text().trimmed().isEmpty()) {
+        foreach (const auto m, mp->availableModes()) {
+            if (m != MimeTreeParser::Util::MultipartPlain) {
+                mode = m;
+                break;
             }
         }
-        MimeMessagePart::Ptr part(mp->mChildParts.first());
-        if (mp->mChildParts.contains(mode)) {
-            part = mp->mChildParts[mode];
-        }
-
-        htmlWriter->queue(render(part));
     }
-    return htmlWriter->html;
+    MimeMessagePart::Ptr part(mp->mChildParts.first());
+    if (mp->mChildParts.contains(mode)) {
+        part = mp->mChildParts[mode];
+    }
+
+    render(part, htmlWriter);
 }
 
-QString DefaultRendererPrivate::render(const CertMessagePart::Ptr &mp)
+void DefaultRendererPrivate::render(const CertMessagePart::Ptr &mp, HtmlWriter *htmlWriter)
 {
     const GpgME::ImportResult &importResult(mp->mImportResult);
     Grantlee::Template t = MessageViewer::MessagePartRendererManager::self()->loadByName(QStringLiteral(
@@ -954,116 +826,83 @@ QString DefaultRendererPrivate::render(const CertMessagePart::Ptr &mp)
         keylist << QVariant::fromValue(key);
     }
 
-    auto htmlWriter = QSharedPointer<CacheHtmlWriter>(new CacheHtmlWriter(mOldWriter));
-    {
-        HTMLBlock::Ptr aBlock;
-        if (mp->isAttachment()) {
-            aBlock
-                = HTMLBlock::Ptr(new AttachmentMarkBlock(htmlWriter.data(), mp->attachmentNode()));
-        }
-        const auto html = t->render(&c);
-        htmlWriter->queue(html);
+    HTMLBlock::Ptr aBlock;
+    if (mp->isAttachment()) {
+        aBlock = HTMLBlock::Ptr(new AttachmentMarkBlock(htmlWriter, mp->attachmentContent()));
     }
-    return htmlWriter->html;
+    Grantlee::OutputStream s(htmlWriter->stream());
+    t->render(&s, &c);
 }
 
-QSharedPointer<PartRendered> DefaultRendererPrivate::renderWithFactory(QString className,
-                                                                       const Interface::MessagePart::Ptr &msgPart)
+bool DefaultRendererPrivate::renderWithFactory(const QMetaObject *mo, const MessagePart::Ptr &msgPart, HtmlWriter *htmlWriter)
 {
-    if (mRendererFactory) {
-        const auto registry = mRendererFactory->typeRegistry(className);
-
-        if (registry.size() > 0) {
-            const auto plugin = registry.at(0);
-            return plugin->render(this, msgPart);
+    if (!mRendererFactory) {
+        return false;
+    }
+    for (auto r : mRendererFactory->renderersForPart(mo, msgPart)) {
+        if (r->render(msgPart, htmlWriter, this)) {
+            return true;
         }
     }
-
-    return QSharedPointer<PartRendered>();
+    return false;
 }
 
-QString DefaultRendererPrivate::renderFactory(const Interface::MessagePart::Ptr &msgPart,
-                                              const QSharedPointer<CacheHtmlWriter> &htmlWriter)
+void DefaultRendererPrivate::renderFactory(const MessagePart::Ptr &msgPart, HtmlWriter *htmlWriter)
 {
     const QString className = QString::fromUtf8(msgPart->metaObject()->className());
 
-    const auto rendered = renderWithFactory(className, msgPart);
-    if (rendered) {
-        const auto parts = rendered->embededParts();
-        foreach (auto key, parts.keys()) {
-            htmlWriter->embedPart(key, parts.value(key));
-        }
-
-        foreach (auto entry, rendered->extraHeader()) {
-            htmlWriter->extraHead(entry);
-        }
-
-        return rendered->html();
+    if (renderWithFactory(msgPart, htmlWriter)) {
+        return;
     }
 
     if (className == QStringLiteral("MimeTreeParser::MessagePartList")) {
         auto mp = msgPart.dynamicCast<MessagePartList>();
         if (mp) {
-            return render(mp);
+            render(mp, htmlWriter);
         }
     } else if (className == QStringLiteral("MimeTreeParser::MimeMessagePart")) {
         auto mp = msgPart.dynamicCast<MimeMessagePart>();
         if (mp) {
-            return render(mp);
+            render(mp, htmlWriter);
         }
     } else if (className == QStringLiteral("MimeTreeParser::EncapsulatedRfc822MessagePart")) {
         auto mp = msgPart.dynamicCast<EncapsulatedRfc822MessagePart>();
         if (mp) {
-            return render(mp);
+            render(mp, htmlWriter);
         }
     } else if (className == QStringLiteral("MimeTreeParser::HtmlMessagePart")) {
         auto mp = msgPart.dynamicCast<HtmlMessagePart>();
         if (mp) {
-            return render(mp);
+            render(mp, htmlWriter);
         }
     } else if (className == QStringLiteral("MimeTreeParser::SignedMessagePart")) {
         auto mp = msgPart.dynamicCast<SignedMessagePart>();
         if (mp) {
-            return render(mp);
+            render(mp, htmlWriter);
         }
     } else if (className == QStringLiteral("MimeTreeParser::EncryptedMessagePart")) {
         auto mp = msgPart.dynamicCast<EncryptedMessagePart>();
         if (mp) {
-            return render(mp);
+            render(mp, htmlWriter);
         }
     } else if (className == QStringLiteral("MimeTreeParser::AlternativeMessagePart")) {
         auto mp = msgPart.dynamicCast<AlternativeMessagePart>();
         if (mp) {
-            return render(mp);
+            render(mp, htmlWriter);
         }
     } else if (className == QStringLiteral("MimeTreeParser::CertMessagePart")) {
         auto mp = msgPart.dynamicCast<CertMessagePart>();
         if (mp) {
-            return render(mp);
+            render(mp, htmlWriter);
         }
+    } else {
+        qCWarning(MESSAGEVIEWER_LOG) << "We got a unkonwn classname, using default behaviour for "
+                                     << className;
     }
-
-    qCDebug(MESSAGEVIEWER_LOG) << "We got a unkonwn classname, using default behaviour for "
-                               << className;
-
-    auto _htmlWriter = htmlWriter;
-    if (!_htmlWriter) {
-        _htmlWriter = QSharedPointer<CacheHtmlWriter>(new CacheHtmlWriter(mOldWriter));
-    }
-    msgPart->setHtmlWriter(_htmlWriter.data());
-    msgPart->html(false);
-    msgPart->setHtmlWriter(mOldWriter);
-    if (!htmlWriter) {
-        return _htmlWriter->html;
-    }
-
-    return QString();
 }
 
-DefaultRenderer::DefaultRenderer(const MimeTreeParser::Interface::MessagePart::Ptr &msgPart,
-                                 CSSHelperBase *cssHelper)
-    : d(new MimeTreeParser::DefaultRendererPrivate(msgPart, cssHelper,
-                                                   rendererPluginFactoryInstance()))
+DefaultRenderer::DefaultRenderer(const MimeTreeParser::MessagePart::Ptr &msgPart, CSSHelperBase *cssHelper, MimeTreeParser::HtmlWriter *writer)
+    : d(new MimeTreeParser::DefaultRendererPrivate(msgPart, cssHelper, writer, MessagePartRendererFactory::instance()))
 {
 }
 
@@ -1071,8 +910,3 @@ DefaultRenderer::~DefaultRenderer()
 {
     delete d;
 }
-
-QString DefaultRenderer::html() const
-{
-    return d->mHtml;
-}
