@@ -22,16 +22,14 @@
 
 #include "../messagepartrendererbase.h"
 
-#include <QSharedPointer>
-
+namespace MessageViewer {
 class AttachmentMessagePartRenderer : public MessagePartRendererBase
 {
 public:
     AttachmentMessagePartRenderer();
     virtual ~AttachmentMessagePartRenderer();
-    QSharedPointer<PartRendered> render(MimeTreeParser::DefaultRendererPrivate *drp,
-                                        const MimeTreeParser::Interface::MessagePartPtr &msgPart)
-    const override;
+    bool render(const MimeTreeParser::MessagePartPtr &msgPart, MimeTreeParser::HtmlWriter *htmlWriter, RenderContext *context) const override;
 };
+}
 
 #endif
