@@ -23,33 +23,14 @@
 
 using namespace MessageViewer;
 
-class ScamCheckShortUrlManagerInstancePrivate
-{
-public:
-    ScamCheckShortUrlManagerInstancePrivate()
-        : scamCheckShortUrlManager(new ScamCheckShortUrlManager)
-    {
-    }
-
-    ~ScamCheckShortUrlManagerInstancePrivate()
-    {
-        delete scamCheckShortUrlManager;
-    }
-
-    ScamCheckShortUrlManager *scamCheckShortUrlManager;
-};
-
-Q_GLOBAL_STATIC(ScamCheckShortUrlManagerInstancePrivate, sInstance)
-
 class MessageViewer::ScamCheckShortUrlManagerPrivate
 {
 public:
     ScamCheckShortUrlManagerPrivate()
-        : mCheckShortUrl(nullptr)
     {
     }
 
-    ScamCheckShortUrl *mCheckShortUrl;
+    ScamCheckShortUrl *mCheckShortUrl = nullptr;
 };
 
 ScamCheckShortUrlManager::ScamCheckShortUrlManager(QObject *parent)
@@ -66,7 +47,8 @@ ScamCheckShortUrlManager::~ScamCheckShortUrlManager()
 
 ScamCheckShortUrlManager *ScamCheckShortUrlManager::self()
 {
-    return sInstance->scamCheckShortUrlManager;
+    static ScamCheckShortUrlManager s_self;
+    return &s_self;
 }
 
 ScamCheckShortUrl *ScamCheckShortUrlManager::scamCheckShortUrl() const
