@@ -83,80 +83,6 @@ using namespace MessageCore;
 URLHandlerManager *URLHandlerManager::self = nullptr;
 
 namespace {
-class KMailActionURLHandler : public MimeTreeParser::URLHandler
-{
-public:
-    KMailActionURLHandler() : MimeTreeParser::URLHandler()
-    {
-    }
-
-    ~KMailActionURLHandler()
-    {
-    }
-
-    bool handleClick(const QUrl &url, ViewerPrivate *viewer) const override
-    {
-        if (url.scheme() == QLatin1String("kmailaction")) {
-            const QString urlPath(url.path());
-            if (urlPath == QStringLiteral("trash")) {
-                viewer->setMailAction(MessageViewer::Viewer::Trash);
-                return true;
-            } else if (urlPath == QStringLiteral("reply")) {
-                viewer->setMailAction(MessageViewer::Viewer::Reply);
-                return true;
-            } else if (urlPath == QStringLiteral("replyToAll")) {
-                viewer->setMailAction(MessageViewer::Viewer::ReplyToAll);
-                return true;
-            } else if (urlPath == QStringLiteral("forward")) {
-                viewer->setMailAction(MessageViewer::Viewer::Forward);
-                return true;
-            } else if (urlPath == QStringLiteral("newMessage")) {
-                viewer->setMailAction(MessageViewer::Viewer::NewMessage);
-                return true;
-            } else if (urlPath == QStringLiteral("print")) {
-                viewer->setMailAction(MessageViewer::Viewer::Print);
-                return true;
-            } else if (urlPath == QStringLiteral("printpreview")) {
-                viewer->setMailAction(MessageViewer::Viewer::PrintPreview);
-                return true;
-            } else {
-                qCDebug(MESSAGEVIEWER_LOG) << "Unknown urlPath " << urlPath;
-            }
-        }
-        return false;
-    }
-
-    bool handleContextMenuRequest(const QUrl &url, const QPoint &, ViewerPrivate *) const override
-    {
-        return url.scheme() == QLatin1String("kmailaction");
-    }
-
-    QString statusBarMessage(const QUrl &url, ViewerPrivate *) const override
-    {
-        if (url.scheme() == QLatin1String("kmailaction")) {
-            const QString urlPath(url.path());
-            if (urlPath == QStringLiteral("trash")) {
-                return i18n("Move To Trash");
-            } else if (urlPath == QStringLiteral("reply")) {
-                return i18n("Reply");
-            } else if (urlPath == QStringLiteral("replyToAll")) {
-                return i18n("Reply To All");
-            } else if (urlPath == QStringLiteral("forward")) {
-                return i18n("Forward");
-            } else if (urlPath == QStringLiteral("newMessage")) {
-                return i18n("New Message");
-            } else if (urlPath == QStringLiteral("print")) {
-                return i18n("Print Message");
-            } else if (urlPath == QStringLiteral("printpreview")) {
-                return i18n("Print Preview Message");
-            } else {
-                qCDebug(MESSAGEVIEWER_LOG) << "Unknown urlPath " << urlPath;
-            }
-        }
-        return QString();
-    }
-};
-
 class KMailProtocolURLHandler : public MimeTreeParser::URLHandler
 {
 public:
@@ -424,35 +350,53 @@ public:
     bool handleContextMenuRequest(const QUrl &, const QPoint &, ViewerPrivate *) const override;
     QString statusBarMessage(const QUrl &, ViewerPrivate *) const override;
 
-    void registerHandler(const MimeTreeParser::Interface::BodyPartURLHandler *handler);
-    void unregisterHandler(const MimeTreeParser::Interface::BodyPartURLHandler *handler);
+    void registerHandler(const Interface::BodyPartURLHandler *handler, const QString &mimeType);
+    void unregisterHandler(const Interface::BodyPartURLHandler *handler);
 
 private:
-    typedef QVector<const MimeTreeParser::Interface::BodyPartURLHandler *> BodyPartHandlerList;
+    QVector<const Interface::BodyPartURLHandler *> handlersForPart(KMime::Content *node) const;
+
+    typedef QHash<QByteArray, QVector<const Interface::BodyPartURLHandler *> > BodyPartHandlerList;
     BodyPartHandlerList mHandlers;
 };
 
 URLHandlerManager::BodyPartURLHandlerManager::~BodyPartURLHandlerManager()
 {
     for_each(mHandlers.begin(), mHandlers.end(),
-             DeleteAndSetToZero<MimeTreeParser::Interface::BodyPartURLHandler>());
+             [](QVector<const Interface::BodyPartURLHandler *> &handlers) {
+        for_each(handlers.begin(), handlers.end(),
+                 DeleteAndSetToZero<Interface::BodyPartURLHandler>());
+    });
 }
 
 void URLHandlerManager::BodyPartURLHandlerManager::registerHandler(
-    const MimeTreeParser::Interface::BodyPartURLHandler *handler)
+    const Interface::BodyPartURLHandler *handler, const QString &mimeType)
 {
     if (!handler) {
         return;
     }
     unregisterHandler(handler);   // don't produce duplicates
-    mHandlers.push_back(handler);
+    const auto mt = mimeType.toLatin1();
+    auto it = mHandlers.find(mt);
+    if (it == mHandlers.end()) {
+        it = mHandlers.insert(mt, {});
+    }
+    it->push_back(handler);
 }
 
 void URLHandlerManager::BodyPartURLHandlerManager::unregisterHandler(
-    const MimeTreeParser::Interface::BodyPartURLHandler *handler)
+    const Interface::BodyPartURLHandler *handler)
 {
     // don't delete them, only remove them from the list!
-    mHandlers.erase(remove(mHandlers.begin(), mHandlers.end(), handler), mHandlers.end());
+    auto it = mHandlers.begin();
+    while (it != mHandlers.end()) {
+        it->erase(remove(it->begin(), it->end(), handler), it->end());
+        if (it->isEmpty()) {
+            it = mHandlers.erase(it);
+        } else {
+            ++it;
+        }
+    }
 }
 
 static KMime::Content *partNodeFromXKMailUrl(const QUrl &url, ViewerPrivate *w, QString *path)
@@ -480,8 +424,19 @@ static KMime::Content *partNodeFromXKMailUrl(const QUrl &url, ViewerPrivate *w,
     return w->nodeFromUrl(QUrl(urlParts.at(1)));
 }
 
-bool URLHandlerManager::BodyPartURLHandlerManager::handleClick(const QUrl &url,
-                                                               ViewerPrivate *w) const
+QVector<const Interface::BodyPartURLHandler *> URLHandlerManager::BodyPartURLHandlerManager::handlersForPart(KMime::Content *node) const
+{
+    if (auto ct = node->contentType(false)) {
+        const auto mimeType = ct->mimeType();
+        if (!mimeType.isEmpty()) {
+            return mHandlers.value(mimeType);
+        }
+    }
+
+    return {};
+}
+
+bool URLHandlerManager::BodyPartURLHandlerManager::handleClick(const QUrl &url, ViewerPrivate *w) const
 {
     QString path;
     KMime::Content *node = partNodeFromXKMailUrl(url, w, &path);
@@ -491,20 +446,19 @@ bool URLHandlerManager::BodyPartURLHandlerManager::handleClick(const QUrl &url,
 
     MimeTreeParser::PartNodeBodyPart part(nullptr, nullptr,
                                           w->message().data(), node, w->nodeHelper());
-    BodyPartHandlerList::const_iterator end(mHandlers.constEnd());
 
-    for (BodyPartHandlerList::const_iterator it = mHandlers.constBegin(); it != end; ++it) {
-        if ((*it)->handleClick(w->viewer(), &part, path)) {
-            return true;
+    for (const auto &handlers : { handlersForPart(node), mHandlers.value({}) }) {
+        for (auto it = handlers.cbegin(), end = handlers.cend(); it != end; ++it) {
+            if ((*it)->handleClick(w->viewer(), &part, path)) {
+                return true;
+            }
         }
     }
 
     return false;
 }
 
-bool URLHandlerManager::BodyPartURLHandlerManager::handleContextMenuRequest(const QUrl &url,
-                                                                            const QPoint &p,
-                                                                            ViewerPrivate *w) const
+bool URLHandlerManager::BodyPartURLHandlerManager::handleContextMenuRequest(const QUrl &url, const QPoint &p, ViewerPrivate *w) const
 {
     QString path;
     KMime::Content *node = partNodeFromXKMailUrl(url, w, &path);
@@ -514,17 +468,18 @@ bool URLHandlerManager::BodyPartURLHandlerManager::handleContextMenuRequest(cons
 
     MimeTreeParser::PartNodeBodyPart part(nullptr, nullptr,
                                           w->message().data(), node, w->nodeHelper());
-    BodyPartHandlerList::const_iterator end(mHandlers.constEnd());
-    for (BodyPartHandlerList::const_iterator it = mHandlers.constBegin(); it != end; ++it) {
-        if ((*it)->handleContextMenuRequest(&part, path, p)) {
-            return true;
+
+    for (const auto &handlers : { handlersForPart(node), mHandlers.value({}) }) {
+        for (auto it = handlers.cbegin(), end = handlers.cend(); it != end; ++it) {
+            if ((*it)->handleContextMenuRequest(&part, path, p)) {
+                return true;
+            }
         }
     }
     return false;
 }
 
-QString URLHandlerManager::BodyPartURLHandlerManager::statusBarMessage(const QUrl &url,
-                                                                       ViewerPrivate *w) const
+QString URLHandlerManager::BodyPartURLHandlerManager::statusBarMessage(const QUrl &url, ViewerPrivate *w) const
 {
     QString path;
     KMime::Content *node = partNodeFromXKMailUrl(url, w, &path);
@@ -534,11 +489,13 @@ QString URLHandlerManager::BodyPartURLHandlerManager::statusBarMessage(const QUr
 
     MimeTreeParser::PartNodeBodyPart part(nullptr, nullptr,
                                           w->message().data(), node, w->nodeHelper());
-    BodyPartHandlerList::const_iterator end(mHandlers.constEnd());
-    for (BodyPartHandlerList::const_iterator it = mHandlers.constBegin(); it != end; ++it) {
-        const QString msg = (*it)->statusBarMessage(&part, path);
-        if (!msg.isEmpty()) {
-            return msg;
+
+    for (const auto &handlers : { handlersForPart(node), mHandlers.value({}) }) {
+        for (auto it = handlers.cbegin(), end = handlers.cend(); it != end; ++it) {
+            const QString msg = (*it)->statusBarMessage(&part, path);
+            if (!msg.isEmpty()) {
+                return msg;
+            }
         }
     }
     return QString();
@@ -563,7 +520,6 @@ URLHandlerManager::URLHandlerManager()
     registerHandler(new ShowAuditLogURLHandler());
     registerHandler(new InternalImageURLHandler);
     registerHandler(new KRunURLHandler());
-    registerHandler(new KMailActionURLHandler());
     //registerHandler(new EmbeddedImageURLHandler());
 }
 
@@ -596,15 +552,14 @@ void URLHandlerManager::unregisterHandler(const MimeTreeParser::URLHandler *hand
     mHandlers.erase(remove(mHandlers.begin(), mHandlers.end(), handler), mHandlers.end());
 }
 
-void URLHandlerManager::registerHandler(const MimeTreeParser::Interface::BodyPartURLHandler *handler)
+void URLHandlerManager::registerHandler(const Interface::BodyPartURLHandler *handler, const QString &mimeType)
 {
     if (mBodyPartURLHandlerManager) {
-        mBodyPartURLHandlerManager->registerHandler(handler);
+        mBodyPartURLHandlerManager->registerHandler(handler, mimeType);
     }
 }
 
-void URLHandlerManager::unregisterHandler(
-    const MimeTreeParser::Interface::BodyPartURLHandler *handler)
+void URLHandlerManager::unregisterHandler(const Interface::BodyPartURLHandler *handler)
 {
     if (mBodyPartURLHandlerManager) {
         mBodyPartURLHandlerManager->unregisterHandler(handler);
@@ -656,8 +611,7 @@ bool URLHandlerManager::handleDrag(const QUrl &url, ViewerPrivate *window) const
     return false;
 }
 
-bool URLHandlerManager::handleContextMenuRequest(const QUrl &url, const QPoint &p,
-                                                 ViewerPrivate *w) const
+bool URLHandlerManager::handleContextMenuRequest(const QUrl &url, const QPoint &p, ViewerPrivate *w) const
 {
     HandlerList::const_iterator end(mHandlers.constEnd());
     for (HandlerList::const_iterator it = mHandlers.constBegin(); it != end; ++it) {
@@ -720,6 +674,12 @@ bool KMailProtocolURLHandler::handleClick(const QUrl &url, ViewerPrivate *w) con
             w->setShowSignatureDetails(false);
             w->update(MimeTreeParser::Force);
             return true;
+        } else if (urlPath == QLatin1String("showEncryptionDetails")) {
+            w->setHideEncryptionDetails(false);
+            return true;
+        } else if (urlPath == QLatin1String("hideEncryptionDetails")) {
+            w->setHideEncryptionDetails(true);
+            return true;
         } else if (urlPath == QLatin1String("showAttachmentQuicklist")) {
             w->setShowAttachmentQuicklist(false);
             return true;
@@ -761,6 +721,10 @@ QString KMailProtocolURLHandler::statusBarMessage(const QUrl &url, ViewerPrivate
             return i18n("Show signature details.");
         } else if (urlPath == QLatin1String("hideSignatureDetails")) {
             return i18n("Hide signature details.");
+        } else if (urlPath == QLatin1String("showEncryptionDetails")) {
+            return i18n("Show encryption details.");
+        } else if (urlPath == QLatin1String("hideEncryptionDetails")) {
+            return i18n("Hide encryption details.");
         } else if (urlPath == QLatin1String("showAttachmentQuicklist")) {
             return i18n("Hide attachment list.");
         } else if (urlPath == QLatin1String("hideAttachmentQuicklist")) {
@@ -951,8 +915,7 @@ bool ContactUidURLHandler::handleClick(const QUrl &url, ViewerPrivate *) const
     }
 }
 
-bool ContactUidURLHandler::handleContextMenuRequest(const QUrl &url, const QPoint &p,
-                                                    ViewerPrivate *) const
+bool ContactUidURLHandler::handleContextMenuRequest(const QUrl &url, const QPoint &p, ViewerPrivate *) const
 {
     if (url.scheme() != QLatin1String("uid") || url.path().isEmpty()) {
         return false;
@@ -1097,8 +1060,7 @@ bool AttachmentURLHandler::handleDrag(const QUrl &url, ViewerPrivate *window) co
     return false;
 }
 
-bool AttachmentURLHandler::handleContextMenuRequest(const QUrl &url, const QPoint &p,
-                                                    ViewerPrivate *w) const
+bool AttachmentURLHandler::handleContextMenuRequest(const QUrl &url, const QPoint &p, ViewerPrivate *w) const
 {
     KMime::Content *node = nodeForUrl(url, w);
     if (!node) {
@@ -1152,8 +1114,7 @@ bool ShowAuditLogURLHandler::handleClick(const QUrl &url, ViewerPrivate *w) cons
     return true;
 }
 
-bool ShowAuditLogURLHandler::handleContextMenuRequest(const QUrl &url, const QPoint &,
-                                                      ViewerPrivate *w) const
+bool ShowAuditLogURLHandler::handleContextMenuRequest(const QUrl &url, const QPoint &, ViewerPrivate *w) const
 {
     Q_UNUSED(w);
     // disable RMB for my own links:
