@@ -21,8 +21,8 @@
 
 #include "utils.h"
 
-#include "viewer/objecttreeparser.h"
-#include "viewer/messagepart.h"
+#include "objecttreeparser.h"
+#include "messagepart.h"
 
 #include <KMime/Content>
 
@@ -56,7 +56,7 @@ bool MailmanBodyPartFormatter::isMailmanMessage(KMime::Content *curNode) const
     return false;
 }
 
-Interface::MessagePart::Ptr MailmanBodyPartFormatter::process(Interface::BodyPart &part) const
+MessagePart::Ptr MailmanBodyPartFormatter::process(Interface::BodyPart &part) const
 {
     KMime::Content *curNode = part.content();
 
