@@ -23,19 +23,14 @@
 #include "interfaces/bodypartformatter.h"
 #include "interfaces/bodypart.h"
 
-namespace MimeTreeParser
-{
-
+namespace MimeTreeParser {
 class MultiPartSignedBodyPartFormatter : public Interface::BodyPartFormatter
 {
     static const MultiPartSignedBodyPartFormatter *self;
 public:
-    Interface::MessagePart::Ptr process(Interface::BodyPart &part) const override;
-    Interface::BodyPartFormatter::Result format(Interface::BodyPart *, HtmlWriter *) const override;
-    using Interface::BodyPartFormatter::format;
+    MessagePartPtr process(Interface::BodyPart &part) const override;
     static const Interface::BodyPartFormatter *create();
 };
-
 }
 
 #endif
