@@ -24,31 +24,25 @@
 #include "templateparserextracthtmlinforesult.h"
 #include <MessageViewer/ObjectTreeEmptySource>
 
-#include <AkonadiCore/Collection>
 #include <KMime/KMimeMessage>
 
 #include <QObject>
 
 class TemplateParserTester;
 
-namespace MimeTreeParser
-{
+namespace MimeTreeParser {
 class ObjectTreeParser;
 }
 
-namespace KIdentityManagement
-{
+namespace KIdentityManagement {
 class IdentityManager;
 }
 
-namespace MessageCore
-{
+namespace MessageCore {
 class ImageCollector;
 }
 
-namespace TemplateParser
-{
-
+namespace TemplateParser {
 /**
  * \brief The TemplateParser transforms a message with a given template.
  *
@@ -212,12 +206,9 @@ public:
      */
     void setCharsets(const QStringList &charsets);
 
-    void process(const KMime::Message::Ptr &aorig_msg,
-                 const Akonadi::Collection &afolder = Akonadi::Collection());
-    void process(const QString &tmplName, const KMime::Message::Ptr &aorig_msg,
-                 const Akonadi::Collection &afolder = Akonadi::Collection());
-    void processWithIdentity(uint uoid, const KMime::Message::Ptr &aorig_msg,
-                             const Akonadi::Collection &afolder = Akonadi::Collection());
+    void process(const KMime::Message::Ptr &aorig_msg, qint64 afolder = -1);
+    void process(const QString &tmplName, const KMime::Message::Ptr &aorig_msg, qint64 afolder = -1);
+    void processWithIdentity(uint uoid, const KMime::Message::Ptr &aorig_msg, qint64 afolder = -1);
 
     void processWithTemplate(const QString &tmpl);
 
@@ -339,8 +330,7 @@ private:
      * after setting the mime type, charset and CTE of its respective text/plain
      * part and text/html part.
      */
-    KMime::Content *createMultipartAlternativeContent(const QString &plainBody,
-            const QString &htmlBody) const;
+    KMime::Content *createMultipartAlternativeContent(const QString &plainBody, const QString &htmlBody) const;
 
     /**
      * Returns a multipart/mixed KMime::Content that has textPart and all
@@ -349,8 +339,7 @@ private:
      * @param textPart a KMime::Content that is to be added as a child.
      * @since 4.8
      */
-    KMime::Content *createMultipartMixed(const QVector<KMime::Content *> &attachments,
-                                         KMime::Content *textPart) const;
+    KMime::Content *createMultipartMixed(const QVector<KMime::Content *> &attachments, KMime::Content *textPart) const;
 
     /**
      * Returnsa multipart/related KMime::Content that has mainTextPart and all
@@ -360,8 +349,7 @@ private:
      * @param mainTextPart a KMime::Content that is to be added as a child.
      * @since 4.8
      */
-    KMime::Content *createMultipartRelated(const MessageCore::ImageCollector &ic,
-                                           KMime::Content *mainTextPart) const;
+    KMime::Content *createMultipartRelated(const MessageCore::ImageCollector &ic, KMime::Content *mainTextPart) const;
 
     /**
      * Checks if the signature is HTML or not.
@@ -382,7 +370,7 @@ private:
     friend class ::TemplateParserTester;
 
     Mode mMode;
-    Akonadi::Collection mFolder;          //Used to find a template
+    qint64 mFolder = -1;          //Used to find a template
     uint mIdentity;
     KMime::Message::Ptr mMsg;             // Msg to write to
     KMime::Message::Ptr mOrigMsg;         // Msg to read from
@@ -391,18 +379,17 @@ private:
     bool mDebug;
     QString mQuoteString;
     QString mTo, mCC;
-    KIdentityManagement::IdentityManager *m_identityManager;
+    KIdentityManagement::IdentityManager *m_identityManager = nullptr;
     bool mWrap;
     int mColWrap;
     QStringList m_charsets;
-    MimeTreeParser::ObjectTreeParser *mOtp;
-    MessageViewer::EmptySource *mEmptySource;
+    MimeTreeParser::ObjectTreeParser *mOtp = nullptr;
+    MessageViewer::EmptySource *mEmptySource = nullptr;
     QString mHeadElement;
     Quotes mQuotes;
     TemplateParserExtractHtmlInfoResult mExtractHtmlInfoResult;
     bool mForceCursorPosition;
 };
-
 }
 
 #endif // TEMPLATEPARSERJOB_H
