@@ -17,19 +17,17 @@
 
 #include "templatestexteditor.h"
 #include "templatesutil_p.h"
-#include "templatessyntaxhighlighterrules.h"
-#include <KPIMTextEdit/TextEditorCompleter>
-#include <KPIMTextEdit/SyntaxHighlighterBase>
 
-#include <QCompleter>
+#include <KPIMTextEdit/TextEditorCompleter>
+#include <KPIMTextEdit/PlainTextSyntaxSpellCheckingHighlighter>
+
+#include <KSyntaxHighlighting/Definition>
+#include <KSyntaxHighlighting/Theme>
+
 #include <QKeyEvent>
-#include <QScrollBar>
-#include <QStringListModel>
 #include <QAbstractItemView>
 #include <QFontDatabase>
-
-#include <kpimtextedit/plaintextsyntaxspellcheckinghighlighter.h>
-
+#include <QCompleter>
 using namespace TemplateParser;
 
 TemplatesTextEditor::TemplatesTextEditor(QWidget *parent)
@@ -52,7 +50,6 @@ TemplatesTextEditor::TemplatesTextEditor(QWidget *parent)
 
 TemplatesTextEditor::~TemplatesTextEditor()
 {
-
 }
 
 void TemplatesTextEditor::updateHighLighter()
@@ -73,8 +70,10 @@ void TemplatesTextEditor::createHighlighter()
     KPIMTextEdit::PlainTextSyntaxSpellCheckingHighlighter *highlighter = new KPIMTextEdit::PlainTextSyntaxSpellCheckingHighlighter(this);
     highlighter->toggleSpellHighlighting(checkSpellingEnabled());
     highlighter->setCurrentLanguage(spellCheckingLanguage());
-    TemplatesSyntaxHighlighterRules rules;
-    highlighter->setSyntaxHighlighterRules(rules.rules());
+    highlighter->setDefinition(mSyntaxRepo.definitionForName(QStringLiteral("KMail Template")));
+    highlighter->setTheme((palette().color(QPalette::Base).lightness() < 128)
+                          ? mSyntaxRepo.defaultTheme(KSyntaxHighlighting::Repository::DarkTheme)
+                          : mSyntaxRepo.defaultTheme(KSyntaxHighlighting::Repository::LightTheme));
     setHighlighter(highlighter);
 }
 
