@@ -25,8 +25,8 @@ using namespace TemplateParser;
 
 void TemplateParser::Util::deleteTemplate(const QString &id)
 {
-    KSharedConfig::Ptr config =
-        KSharedConfig::openConfig(QStringLiteral("templatesconfigurationrc"), KConfig::NoGlobals);
+    KSharedConfig::Ptr config
+        = KSharedConfig::openConfig(QStringLiteral("templatesconfigurationrc"), KConfig::NoGlobals);
 
     const QString key = QStringLiteral("Templates #%1").arg(id);
     if (config->hasGroup(key)) {
@@ -54,24 +54,6 @@ QStringList TemplateParser::Util::keywordsWithArgs()
     return keywordsWithArgs;
 }
 
-QStringList TemplateParser::Util::keywordsWithArgsForCompleter()
-{
-    const QStringList keywordsWithArgs = QStringList()
-                                         << QStringLiteral("%REM=\".*\"%-")
-                                         << QStringLiteral("%INSERT=\".*\"")
-                                         << QStringLiteral("%SYSTEM=\".*\"")
-                                         << QStringLiteral("%QUOTEPIPE=\".*\"")
-                                         << QStringLiteral("%MSGPIPE=\".*\"")
-                                         << QStringLiteral("%BODYPIPE=\".*\"")
-                                         << QStringLiteral("%CLEARPIPE=\".*\"")
-                                         << QStringLiteral("%TEXTPIPE=\".*\"")
-                                         << QStringLiteral("%OHEADER=\".*\"")
-                                         << QStringLiteral("%HEADER=\".*\"")
-                                         << QStringLiteral("%DICTIONARYLANGUAGE=\".*\"")
-                                         << QStringLiteral("%LANGUAGE=\".*\"");
-    return keywordsWithArgs;
-}
-
 QStringList TemplateParser::Util::keywords()
 {
     const QStringList keywords = QStringList()
