@@ -17,7 +17,6 @@
    Boston, MA 02110-1301, USA.
 */
 #include "webenginescript.h"
-#include <QDebug>
 
 using namespace WebEngineViewer;
 
@@ -100,37 +99,37 @@ QString WebEngineScript::findAllAnchorsAndForms()
 QString WebEngineScript::setElementByIdVisible(const QString &elementStr, bool visibility)
 {
     if (visibility) {
-        const QString source = QString::fromLatin1("var element = document.getElementById('%1'); "
-                               "if (element) { "
-                               "    element.style.removeProperty( 'display' );"
-                               "}").arg(elementStr);
+        const QString source = QStringLiteral("var element = document.getElementById('%1'); "
+                                                   "if (element) { "
+                                                   "    element.style.removeProperty( 'display' );"
+                                                   "}").arg(elementStr);
         return source;
     } else {
-        const QString source = QString::fromLatin1("var element = document.getElementById('%1'); "
-                               "if (element) { "
-                               "    element.style.display = \"none\";"
-                               "}").arg(elementStr);
+        const QString source = QStringLiteral("var element = document.getElementById('%1'); "
+                                                   "if (element) { "
+                                                   "    element.style.display = \"none\";"
+                                                   "}").arg(elementStr);
         return source;
     }
 }
 
 QString WebEngineScript::searchElementPosition(const QString &elementStr)
 {
-    const QString source = QString::fromLatin1("var element = document.getElementById('%1'); "
-                           "if (element) { "
-                           "    var geometry = element.getBoundingClientRect(); "
-                           "    [(geometry.left + window.scrollX), (geometry.top + window.scrollY)]; "
-                           "}").arg(elementStr);
+    const QString source = QStringLiteral("var element = document.getElementById('%1'); "
+                                               "if (element) { "
+                                               "    var geometry = element.getBoundingClientRect(); "
+                                               "    [(geometry.left + window.scrollX), (geometry.top + window.scrollY)]; "
+                                               "}").arg(elementStr);
     return source;
 }
 
 QString WebEngineScript::scrollPercentage(int percent)
 {
-    const QString source = QString::fromLatin1("var current = document.body.scrollTop;"
-                           "var docElement = document.documentElement;"
-                           "var height = docElement.clientHeight;"
-                           "var newPosition = current + height * %1 /100;"
-                           "window.scrollTo(window.scrollX, newPosition);").arg(percent);
+    const QString source = QStringLiteral("var current = document.body.scrollTop;"
+                                               "var docElement = document.documentElement;"
+                                               "var height = docElement.clientHeight;"
+                                               "var newPosition = current + height * %1 /100;"
+                                               "window.scrollTo(window.scrollX, newPosition);").arg(percent);
     return source;
 }
 
@@ -142,43 +141,43 @@ QString WebEngineScript::scrollUp(int pixel)
 
 QString WebEngineScript::scrollDown(int pixel)
 {
-    const QString source = QString::fromLatin1("window.scrollBy(0, %1);").arg(pixel);
+    const QString source = QStringLiteral("window.scrollBy(0, %1);").arg(pixel);
     return source;
 }
 
 QString WebEngineScript::scrollToPosition(const QPoint &pos)
 {
-    const QString source = QString::fromLatin1("window.scrollTo(%1, %2); [window.scrollX, window.scrollY];").arg(pos.x(), pos.y());
+    const QString source = QStringLiteral("window.scrollTo(%1, %2); [window.scrollX, window.scrollY];").arg(pos.x(), pos.y());
     return source;
 }
 
 QString WebEngineScript::removeStyleToElement(const QString &elementStr)
 {
-    const QString source = QString::fromLatin1("var element = document.getElementById('%1'); "
-                           "if (element) { "
-                           "    element.removeAttribute(\"style\");"
-                           "}").arg(elementStr);
+    const QString source = QStringLiteral("var element = document.getElementById('%1'); "
+                                               "if (element) { "
+                                               "    element.removeAttribute(\"style\");"
+                                               "}").arg(elementStr);
     return source;
 }
 
 QString WebEngineScript::setStyleToElement(const QString &elementStr, const QString &style)
 {
-    const QString source = QString::fromLatin1("var element = document.getElementById('%1'); "
-                           "if (element) { "
-                           "    element.style = '%2';"
-                           "}").arg(elementStr, style);
+    const QString source = QStringLiteral("var element = document.getElementById('%1'); "
+                                               "if (element) { "
+                                               "    element.style = '%2';"
+                                               "}").arg(elementStr, style);
     return source;
 }
 
 QString WebEngineScript::scrollToRelativePosition(qreal pos)
 {
-    const QString source = QString::fromLatin1("window.scrollTo(window.scrollX, %1); [window.scrollX, window.scrollY];").arg(pos);
+    const QString source = QStringLiteral("window.scrollTo(window.scrollX, %1); [window.scrollX, window.scrollY];").arg(pos);
     return source;
 }
 
 QString WebEngineScript::isScrolledToBottom()
 {
-    return QString::fromLatin1("(function() { "
+    return QStringLiteral("(function() { "
                                "var docElement = document.documentElement;"
                                "var viewportHeight = docElement.clientHeight;"
                                "var isAtBottom = document.body.scrollTop + viewportHeight >= document.body.scrollHeight;"
